"use strict";
//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HtmlEditorFloatHighlightToolbar = exports.HtmlEditorFloatHighlightToolbarContent = void 0;
var react_1 = __importDefault(require("react"));
var primeobjects_ui_web_basic_1 = require("primeobjects-ui-web-basic");
var primeobjects_helper_util_1 = require("primeobjects-helper-util");
var react_2 = require("@tiptap/react");
var lodash_1 = require("lodash");
var html_helper_1 = require("./html-helper");
var HtmlEditorFloatHighlightToolbarContent = function (props) {
    var editor = props.editor;
    var customButtons = (0, lodash_1.isArray)(props.customButtons) ? props.customButtons : [];
    var colors = (0, lodash_1.isArray)(props.colors) && props.colors.length > 0 ? props.colors : ["red", "orange", "blue", "green", "gray"];
    var COLORS = primeobjects_helper_util_1.COLORS;
    var onClickCustomButton = function (button) {
        var text = (0, html_helper_1.getSelectedHightlightText)(editor);
        var currentColor = (0, html_helper_1.getSelectedHightlightColor)(editor);
        //get colorName
        var colorName = (0, lodash_1.find)(colors, function (colorName) {
            return COLORS[colorName.toUpperCase()]["100"] == currentColor;
        });
        button.onClick(editor, text, (0, lodash_1.isNil)(colorName) ? "" : colorName);
    };
    var onApplyColor = function (color) {
        var currentColor = (0, html_helper_1.getSelectedHightlightColor)(editor);
        if (currentColor == color) {
            editor.chain().focus().unsetHighlight().run();
        }
        else {
            editor.chain().focus().toggleHighlight({ color: color }).run();
        }
        if ((0, lodash_1.isFunction)(props.onHighlight))
            props.onHighlight(editor, color);
    };
    var renderColorPicker = function () {
        var currentColor = (0, html_helper_1.getSelectedHightlightColor)(editor);
        return (0, lodash_1.map)(colors, function (colorName) {
            var color = COLORS[colorName.toUpperCase()]["100"];
            var isActive = color == currentColor;
            return (react_1.default.createElement("div", { className: "menu", key: color },
                react_1.default.createElement("div", { onClick: function () { return onApplyColor(color); }, style: { backgroundColor: color, margin: 2, marginTop: 4, marginBottom: 4, padding: 4 }, className: "menu-color ".concat(isActive ? "active" : "") }, isActive && react_1.default.createElement(primeobjects_ui_web_basic_1.SVG, { src: "/icons/platform/checkmark.svg", size: 11 }))));
        });
    };
    var renderCustomButtons = function () {
        return (0, lodash_1.map)(customButtons, function (customButton, index) {
            return (react_1.default.createElement("div", { key: index, className: "menu flex", style: { marginTop: 2, marginLeft: 2 } },
                react_1.default.createElement("div", { onClick: function () { return onClickCustomButton(customButton); }, className: "menu-color", style: { width: 18, height: 18 } },
                    react_1.default.createElement(primeobjects_ui_web_basic_1.SVG, { src: "/icons/platform/note.svg", size: 18 }))));
        });
    };
    return (react_1.default.createElement("div", { className: "menu w-full" },
        renderColorPicker(),
        renderCustomButtons()));
};
exports.HtmlEditorFloatHighlightToolbarContent = HtmlEditorFloatHighlightToolbarContent;
var HtmlEditorFloatHighlightToolbar = function (props) {
    return (0, lodash_1.isNil)(props.editor) ? (react_1.default.createElement(react_1.default.Fragment, null)) : (react_1.default.createElement(react_2.BubbleMenu, { editor: props.editor, className: "menu-wrapper highlight-toolbar ".concat(props.wrapperClassName) },
        react_1.default.createElement(exports.HtmlEditorFloatHighlightToolbarContent, __assign({}, props))));
};
exports.HtmlEditorFloatHighlightToolbar = HtmlEditorFloatHighlightToolbar;
exports.default = exports.HtmlEditorFloatHighlightToolbar;
//# sourceMappingURL=html-float-highlight-toolbar.js.map