//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React from "react";
import { SVG } from "primeobjects-ui-web-basic";
import { COLORS as COLORS_LIST } from "primeobjects-helper-util";
import { BubbleMenu } from "@tiptap/react";
import { isFunction, map, isArray, isNil, find } from "lodash";
import { getSelectedHightlightColor, getSelectedHightlightText } from "./html-helper";
export var HtmlEditorFloatHighlightToolbarContent = function (props) {
    var editor = props.editor;
    var customButtons = isArray(props.customButtons) ? props.customButtons : [];
    var colors = isArray(props.colors) && props.colors.length > 0 ? props.colors : ["red", "orange", "blue", "green", "gray"];
    var COLORS = COLORS_LIST;
    var onClickCustomButton = function (button) {
        var text = getSelectedHightlightText(editor);
        var currentColor = getSelectedHightlightColor(editor);
        //get colorName
        var colorName = find(colors, function (colorName) {
            return COLORS[colorName.toUpperCase()]["100"] == currentColor;
        });
        button.onClick(editor, text, isNil(colorName) ? "" : colorName);
    };
    var onApplyColor = function (color) {
        var currentColor = getSelectedHightlightColor(editor);
        if (currentColor == color) {
            editor.chain().focus().unsetHighlight().run();
        }
        else {
            editor.chain().focus().toggleHighlight({ color: color }).run();
        }
        if (isFunction(props.onHighlight))
            props.onHighlight(editor, color);
    };
    var renderColorPicker = function () {
        var currentColor = getSelectedHightlightColor(editor);
        return map(colors, function (colorName) {
            var color = COLORS[colorName.toUpperCase()]["100"];
            var isActive = color == currentColor;
            return (React.createElement("div", { className: "menu", key: color },
                React.createElement("div", { onClick: function () { return onApplyColor(color); }, style: { backgroundColor: color, margin: 2, marginTop: 4, marginBottom: 4, padding: 4 }, className: "menu-color ".concat(isActive ? "active" : "") }, isActive && React.createElement(SVG, { src: "/icons/platform/checkmark.svg", size: 11 }))));
        });
    };
    var renderCustomButtons = function () {
        return map(customButtons, function (customButton, index) {
            return (React.createElement("div", { key: index, className: "menu flex", style: { marginTop: 2, marginLeft: 2 } },
                React.createElement("div", { onClick: function () { return onClickCustomButton(customButton); }, className: "menu-color", style: { width: 18, height: 18 } },
                    React.createElement(SVG, { src: "/icons/platform/note.svg", size: 18 }))));
        });
    };
    return (React.createElement("div", { className: "menu w-full" },
        renderColorPicker(),
        renderCustomButtons()));
};
export var HtmlEditorFloatHighlightToolbar = function (props) {
    return isNil(props.editor) ? (React.createElement(React.Fragment, null)) : (React.createElement(BubbleMenu, { editor: props.editor, className: "menu-wrapper highlight-toolbar ".concat(props.wrapperClassName) },
        React.createElement(HtmlEditorFloatHighlightToolbarContent, __assign({}, props))));
};
export default HtmlEditorFloatHighlightToolbar;
//# sourceMappingURL=html-float-highlight-toolbar.js.map